PackageMetadataBuilder class

Mixed-in types

Constructors

PackageMetadataBuilder(BuilderOptions options)

Properties

buildExtensions Map<String, List<String>>
Mapping from input file extension to output file extensions.
no setter
hashCode int
The hash code for this object.
no setterinherited
options → BuilderOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strictTypes bool
no setter

Methods

build(BuildStep buildStep) Future<void>
Generates the outputs for a given BuildStep.
createDartCode(Spec spec, {bool scoped = true, bool format = false, Uri? uri}) String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeDartCode(BuildStep buildStep, AssetId assetId, Spec spec, {bool scoped = true, bool format = true}) Future<void>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited